summaryrefslogtreecommitdiff
path: root/pcl
diff options
context:
space:
mode:
authorHenry Stiles <henry.stiles@artifex.com>2011-11-07 10:53:09 -0700
committerHenry Stiles <henry.stiles@artifex.com>2011-11-07 10:56:18 -0700
commit91ce46e08ae37a9c5116bc379b7712c10df5a8f2 (patch)
tree963db981cafa6eb79f0502fe8ff47c8c27034057 /pcl
parenta4230e24b386ac647b0562cb2bf34c25043a1903 (diff)
Fix 692614 - the unsolid pattern should be used when the gl/2 white
pattern is specified. Also, progressions noted in PCL5 CET 32-01.
Diffstat (limited to 'pcl')
-rw-r--r--pcl/pcpatrn.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/pcl/pcpatrn.c b/pcl/pcpatrn.c
index a64b6ef52..131b0165a 100644
--- a/pcl/pcpatrn.c
+++ b/pcl/pcpatrn.c
@@ -1016,8 +1016,11 @@ pattern_set_shade_gl(
{
pcl_pattern_t * pptrn = pcl_pattern_get_shade(pcs, inten);
- /* check if the current pen is white; if so, use the "unsolid" pattern */
- if (pcl_cs_indexed_is_white(pcs->ppalet->pindexed, pen))
+ /* check if the current pen is white or the pattern is transparent
+ and the intensity is 0 (white) and if so use the unsolid
+ pattern */
+ if (pcl_cs_indexed_is_white(pcs->ppalet->pindexed, pen) ||
+ (pcs->pattern_transparent && inten == 0))
pptrn = pcl_pattern_get_unsolid_pattern(pcs);
else if (pptrn == 0)
return ( inten > 0 ? pattern_set_pen(pcs, pen, false)